<?php
/**
 * Widgets
 *
 */

/**
 * Featured Posts widget
 */
class newspaper_mag_featured_posts_widget extends WP_Widget {

   function __construct() {
      $widget_ops = array( 'classname' => 'widget_featured_posts newspaper-mag-widget row', 'description' =>__( 'Display latest posts or posts of specific category. Only for Front Page: Content Section!' , 'newspaper-mag') );
      $control_ops = array( 'width' => 200, 'height' =>250 );
      parent::__construct( false,$name= __( 'First Mag: Category Widget 1', 'newspaper-mag' ),$widget_ops);
   }

   function form( $instance ) {
      $newspaper_mag_defaults['title'] = '';
      $newspaper_mag_defaults['text'] = '';
      $newspaper_mag_defaults['number'] = 12;
      $newspaper_mag_defaults['meta'] = 'off';
      $newspaper_mag_defaults['type'] = 'latest';
      $newspaper_mag_defaults['category'] = '';
      $instance = wp_parse_args( (array) $instance, $newspaper_mag_defaults );
      $title = esc_attr( $instance[ 'title' ] );
      $text = esc_textarea($instance['text']);
      $number = $instance['number'];
      $type = $instance['type'];
      $category = $instance['category'];
      $meta = $instance['meta'];  
      ?>
      <p><?php _e( 'Widget Layout:', 'newspaper-mag' ) ?></p>
      <div style="text-align: center;"><img src="<?php echo get_template_directory_uri() . '/img/feat-cat1.jpg'?>"></div>
      <p>
         <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e( 'Title:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
      </p>
      <?php _e( 'Description','newspaper-mag' ); ?>
      <textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>
      <p>
         <label for="<?php echo $this->get_field_id('number'); ?>"><?php _e( 'Number of posts to display:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" />
      </p>
      <p>
        <label for="<?php echo $this->get_field_id( 'meta' ); ?>"><?php _e( 'Enable or disable post meta', 'newspaper-mag' ); ?>:</label><br />
        <input type="radio" <?php checked($meta, 'on') ?> id="<?php echo $this->get_field_id( 'meta' ); ?>" name="<?php echo $this->get_field_name( 'meta' ); ?>" value="on"/><?php _e( 'Enable', 'newspaper-mag' );?><br />
        <input type="radio" <?php checked($meta,'off') ?> id="<?php echo $this->get_field_id( 'meta' ); ?>" name="<?php echo $this->get_field_name( 'meta' ); ?>" value="off"/><?php _e( 'Disable', 'newspaper-mag' );?><br />
      </p>
      <p><input type="radio" <?php checked($type, 'latest') ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="latest"/><?php _e( 'Show latest Posts', 'newspaper-mag' );?><br />
       <input type="radio" <?php checked($type,'category') ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="category"/><?php _e( 'Show posts from a category:', 'newspaper-mag' );?><br /></p>

      <p>
         <label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Select category', 'newspaper-mag' ); ?>:</label>
         <?php wp_dropdown_categories( array( 'show_option_none' =>' ','name' => $this->get_field_name( 'category' ), 'selected' => $category ) ); ?>
      </p>
      <?php
   }

   function update( $new_instance, $old_instance ) {
      $instance = $old_instance;
      $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
      $instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) );
      $instance[ 'number' ] = absint( $new_instance[ 'number' ] );
      $instance[ 'type' ] = strip_tags( $new_instance[ 'type' ] );
      $instance[ 'category' ] = absint( $new_instance[ 'category' ] );
      $instance[ 'meta' ] = strip_tags( $new_instance[ 'meta' ] );
      return $instance;
   }

   function widget( $args, $instance ) {
      extract( $args );
      extract( $instance );

      global $post;
      $title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '';
      $text = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
      $number = empty( $instance[ 'number' ] ) ? 5 : $instance[ 'number' ];
      $type = isset( $instance[ 'type' ] ) ? $instance[ 'type' ] : 'latest' ;
      $category = isset( $instance[ 'category' ] ) ? $instance[ 'category' ] : '';
      $meta = isset( $instance[ 'meta' ] ) ? $instance[ 'meta' ] : 'off' ;
      
      
      $category_link = get_category_link( $category ); 
      if ($category !='' && $type != 'latest' ) { 
          $cat_link = esc_url( $category_link );
      } else {
          $cat_link = get_permalink( get_option( 'page_for_posts' )); 
      }
       
      if( $type == 'latest' ) {
         $get_posts = new WP_Query( array(
            'posts_per_page'        => $number,
            'post_type'             => 'post',
            'ignore_sticky_posts'   => true
         ) );
      }
      else {
         $get_posts = new WP_Query( array(
            'posts_per_page'        => $number,
            'post_type'             => 'post',
            'category__in'          => $category
         ) );
      }
      echo $before_widget;
      ?>
      <?php
         if ( !empty( $title ) ) { echo $before_title . esc_html( $title ) . $after_title; }
         if( !empty( $text ) ) { ?> <p class="widget-description col-md-12"> <?php echo esc_textarea( $text ); ?> </p> <?php }          
         $i=1;
         while( $get_posts->have_posts() ) : $get_posts->the_post();
         if( $i == 1 ) { echo '<div class="first-post col-sm-5">'; } elseif ( $i == 2 ) { echo '<div class="small-post col-sm-7 no-gutter">'; } ?>
               <article > 
                <div <?php post_class(); ?>>                            
                  <?php if( $i == 1 ) : ?>
                    <div class="featured-thumbnail col-md-12">
                      <a href="<?php the_permalink(); ?>" rel="bookmark">   
                        <?php if ( has_post_thumbnail() ) : ?>                             
                          <?php the_post_thumbnail('newspaper-mag-home'); ?>                                                           
                        <?php elseif ( !has_post_thumbnail() ) : ?>
                          <img src="<?php echo get_template_directory_uri(); ?>/img/noprew-related.jpg" alt="<?php the_title(); ?>">                                                           
                        <?php endif; ?>
                      </a>
                    </div>
                  <?php endif; ?> 
                  <div class="home-header col-md-12"> 
                  <header>
                  <h2 class="page-header">                                
                    <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( sprintf( __( 'Permalink to %s', 'newspaper-mag' ), the_title_attribute( 'echo=0' ) ) ); ?>" rel="bookmark">
                      <?php the_title(); ?>
                    </a>                            
                  </h2> 
                  <?php if( $meta == 'on') : ?>
                    <?php get_template_part('template-part', 'postmeta'); ?>
                  <?php endif; ?>   
                  </header>                                                      
                  <?php if( $i == 1 ) : ?>
                    <div class="entry-summary">
                  		<?php $content = get_the_content();  echo wp_trim_words( strip_shortcodes($content) , '20', $more = '...' ); ?> 
                  	</div><!-- .entry-summary -->                                                                                                                       
                  <?php endif; ?>                                         
                  </div>                      
                </div>
                </article>
            <?php if( $i == 1 ) { echo '</div>'; } ?>
         <?php
            $i++;
         endwhile;
         if ( $i > 2 ) { echo '</div>'; }
         // Reset Post Data
         wp_reset_query();
         ?>
         <?php if ($type == 'category') { ?>
           <div class="widget-footer col-md-12 text-right">
              <a class="btn btn-primary btn-xs" href="<?php echo esc_url( $cat_link ); ?>" >
                  <?php _e( 'All ', 'newspaper-mag' )?><?php $categorys = get_category($category); echo esc_attr( $categorys->category_count ); ?><?php _e( ' Articles', 'newspaper-mag' )?>
              </a>
            </div>
          <?php } elseif ($type == 'latest' && get_option('page_for_posts') == true ) { ?>
           <div class="widget-footer col-md-12 text-right">
              <a class="btn btn-primary btn-xs" href="<?php echo get_post_type_archive_link( 'post' ); ?>" >
                  <?php _e( 'All ', 'newspaper-mag' )?><?php $count_posts = wp_count_posts(); echo $count_posts->publish; ?><?php _e( ' Articles', 'newspaper-mag' )?>
              </a>
            </div>
          <?php } ?> 
      <!-- </div> -->
      <?php echo $after_widget;
      }
}


/**
 * Featured Posts widget 2
 */
class newspaper_mag_featured_posts_widget_second extends WP_Widget {

   function __construct() {
      $widget_ops = array( 'classname' => 'widget_featured_posts_second newspaper-mag-widget row', 'description' =>__( 'Display latest posts or posts of specific category. Only for Front Page: Content Section!' , 'newspaper-mag') );
      $control_ops = array( 'width' => 200, 'height' =>250 );
      parent::__construct( false,$name= __( 'First Mag: Category Widget 2', 'newspaper-mag' ),$widget_ops);
   }

   function form( $instance ) {
      $newspaper_mag_defaults['title'] = '';
      $newspaper_mag_defaults['text'] = '';
      $newspaper_mag_defaults['number'] = 6;
      $newspaper_mag_defaults['meta'] = 'off';
      $newspaper_mag_defaults['type'] = 'latest';
      $newspaper_mag_defaults['category'] = '';
      $instance = wp_parse_args( (array) $instance, $newspaper_mag_defaults );
      $title = esc_attr( $instance[ 'title' ] );
      $text = esc_textarea($instance['text']);
      $number = $instance['number'];
      $type = $instance['type'];
      $category = $instance['category'];
      $meta = $instance['meta'];  
      ?>
      <p><?php _e( 'Widget Layout:', 'newspaper-mag' ) ?></p>
      <div style="text-align: center;"><img src="<?php echo get_template_directory_uri() . '/img/feat-cat2.jpg'?>"></div>
      <p>
         <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e( 'Title:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
      </p>
      <?php _e( 'Description','newspaper-mag' ); ?>
      <textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>
      <p>
         <label for="<?php echo $this->get_field_id('number'); ?>"><?php _e( 'Number of posts to display:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" />
      </p>
      <p>
        <label for="<?php echo $this->get_field_id( 'meta' ); ?>"><?php _e( 'Enable or disable post meta', 'newspaper-mag' ); ?>:</label><br />
        <input type="radio" <?php checked($meta, 'on') ?> id="<?php echo $this->get_field_id( 'meta' ); ?>" name="<?php echo $this->get_field_name( 'meta' ); ?>" value="on"/><?php _e( 'Enable', 'newspaper-mag' );?><br />
        <input type="radio" <?php checked($meta,'off') ?> id="<?php echo $this->get_field_id( 'meta' ); ?>" name="<?php echo $this->get_field_name( 'meta' ); ?>" value="off"/><?php _e( 'Disable', 'newspaper-mag' );?><br />
      </p>
      <p><input type="radio" <?php checked($type, 'latest') ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="latest"/><?php _e( 'Show latest Posts', 'newspaper-mag' );?><br />
       <input type="radio" <?php checked($type,'category') ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="category"/><?php _e( 'Show posts from a category:', 'newspaper-mag' );?><br /></p>

      <p>
         <label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Select category', 'newspaper-mag' ); ?>:</label>
         <?php wp_dropdown_categories( array( 'show_option_none' =>' ','name' => $this->get_field_name( 'category' ), 'selected' => $category ) ); ?>
      </p>
      <?php
   }

   function update( $new_instance, $old_instance ) {
      $instance = $old_instance;
      $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
      $instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) );
      $instance[ 'number' ] = absint( $new_instance[ 'number' ] );
      $instance[ 'type' ] = strip_tags( $new_instance[ 'type' ] );
      $instance[ 'category' ] = absint( $new_instance[ 'category' ] );
      $instance[ 'meta' ] = strip_tags( $new_instance[ 'meta' ] );
      return $instance;
   }

   function widget( $args, $instance ) {
      extract( $args );
      extract( $instance );

      global $post;
      $title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '';
      $text = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
      $number = empty( $instance[ 'number' ] ) ? 5 : $instance[ 'number' ];
      $type = isset( $instance[ 'type' ] ) ? $instance[ 'type' ] : 'latest' ;
      $category = isset( $instance[ 'category' ] ) ? $instance[ 'category' ] : '';
      $meta = isset( $instance[ 'meta' ] ) ? $instance[ 'meta' ] : 'off' ;
      
      
      $category_link = get_category_link( $category ); 
      if ($category !='' && $type != 'latest' ) { 
          $cat_link = esc_url( $category_link );
      } else {
          $cat_link = get_permalink( get_option( 'page_for_posts' )); 
      }
       
      if( $type == 'latest' ) {
         $get_posts = new WP_Query( array(
            'posts_per_page'        => $number,
            'post_type'             => 'post',
            'ignore_sticky_posts'   => true
         ) );
      }
      else {
         $get_posts = new WP_Query( array(
            'posts_per_page'        => $number,
            'post_type'             => 'post',
            'category__in'          => $category
         ) );
      }
      echo $before_widget;
      ?>
      <?php
         if ( !empty( $title ) ) { echo $before_title . esc_html( $title ) . $after_title; }
         if( !empty( $text ) ) { ?> <p class="widget-description col-md-12"> <?php echo esc_textarea( $text ); ?> </p> <?php } 
         $i=1;
         while( $get_posts->have_posts() ) : $get_posts->the_post();
         if( $i == 1 ) { $grid_block = 'col-sm-7'; } else { $grid_block = '';} ?>
            <?php if( $i == 1 ) { echo '<div class="first-post first-padding col-md-12">'; } elseif ( $i == 2 ) { echo '<div class="small-post col-md-12 no-gutter">'; } ?>
               <article> 
                <div <?php post_class(); ?>>                            
                  <?php if( $i == 1 ) : ?>
                    <div class="featured-thumbnail col-sm-5">
                      <a href="<?php the_permalink(); ?>" rel="bookmark">   
                        <?php if ( has_post_thumbnail() ) : ?>                             
                          <?php the_post_thumbnail('newspaper-mag-home'); ?>                                                           
                        <?php elseif ( !has_post_thumbnail() ) : ?>
                          <img src="<?php echo get_template_directory_uri(); ?>/img/noprew-related.jpg" alt="<?php the_title(); ?>">                                                           
                        <?php endif; ?>
                      </a>
                    </div>
                  <?php endif; ?>  
                  <div class="home-header <?php echo $grid_block; ?>"> 
                  <header>
                  <h2 class="page-header">                                
                    <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( sprintf( __( 'Permalink to %s', 'newspaper-mag' ), the_title_attribute( 'echo=0' ) ) ); ?>" rel="bookmark">
                      <?php the_title(); ?>
                    </a>                            
                  </h2> 
                  <?php if( $meta == 'on') : ?>
                    <?php get_template_part('template-part', 'postmeta'); ?>
                  <?php endif; ?>   
                  </header>                                                      
                  <?php if( $i == 1 ) : ?>
                    <div class="entry-summary">
                  		<?php $content = get_the_content();  echo wp_trim_words( strip_shortcodes($content) , '25', $more = '...' ); ?> 
                  	</div><!-- .entry-summary -->                                                                                                                       
                  <?php endif; ?>                                         
                  </div>                      
                </div>
                </article>
            <?php if( $i == 1 ) { echo '</div>'; } ?>
         <?php
            $i++;
         endwhile;
         if ( $i > 2 ) { echo '</div>'; }
         // Reset Post Data
         wp_reset_query();
         ?>
         <?php if ($type == 'category') { ?>
           <div class="widget-footer col-md-12 text-right">
              <a class="btn btn-primary btn-xs" href="<?php echo esc_url( $cat_link ); ?>" >
                  <?php _e( 'All ', 'newspaper-mag' )?><?php $categorys = get_category($category); echo esc_attr( $categorys->category_count ); ?><?php _e( ' Articles', 'newspaper-mag' )?>
              </a>
            </div>
          <?php } elseif ($type == 'latest' && get_option('page_for_posts') == true ) { ?>
           <div class="widget-footer col-md-12 text-right">
              <a class="btn btn-primary btn-xs" href="<?php echo get_post_type_archive_link( 'post' ); ?>" >
                  <?php _e( 'All ', 'newspaper-mag' )?><?php $count_posts = wp_count_posts(); echo $count_posts->publish; ?><?php _e( ' Articles', 'newspaper-mag' )?>
              </a>
            </div>
          <?php } ?> 
      <!-- </div> -->
      <?php echo $after_widget;
      }
}



/**
 * Featured FullWidth post Widget
 */
class newspaper_mag_img_posts_widget extends WP_Widget {

   function __construct() {
      $widget_ops = array( 'classname' => 'widget_img_posts newspaper-mag-widget row', 'description' =>__( 'Display latest posts or posts of specific category. Only for Front Page: Content Section!' , 'newspaper-mag') );
      $control_ops = array( 'width' => 200, 'height' =>250 );
      parent::__construct( false,$name= __( 'First Mag: Images post widget', 'newspaper-mag' ),$widget_ops);
   }

   function form( $instance ) {
      $newspaper_mag_defaults['title'] = '';
      $newspaper_mag_defaults['text'] = '';
      $newspaper_mag_defaults['number'] = 3;
      $newspaper_mag_defaults['meta'] = 'off';
      $newspaper_mag_defaults['type'] = 'latest';
      $newspaper_mag_defaults['category'] = '';
      $instance = wp_parse_args( (array) $instance, $newspaper_mag_defaults );
      $title = esc_attr( $instance[ 'title' ] );
      $text = esc_textarea($instance['text']);
      $number = $instance['number'];
      $type = $instance['type'];
      $category = $instance['category'];
      $meta = $instance['meta'];  
      ?>
      <p><?php _e( 'Widget Layout:', 'newspaper-mag' ) ?></p>
      <div style="text-align: center;"><img src="<?php echo get_template_directory_uri() . '/img/fullwidth-cat.jpg'?>"></div>
      <p>
         <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e( 'Title:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
      </p>
      <?php _e( 'Description','newspaper-mag' ); ?>
      <textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>
      <p>
         <label for="<?php echo $this->get_field_id('number'); ?>"><?php _e( 'Number of posts to display:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" />
      </p>
      <p>
        <label for="<?php echo $this->get_field_id( 'meta' ); ?>"><?php _e( 'Enable or disable post meta', 'newspaper-mag' ); ?>:</label><br />
        <input type="radio" <?php checked($meta, 'on') ?> id="<?php echo $this->get_field_id( 'meta' ); ?>" name="<?php echo $this->get_field_name( 'meta' ); ?>" value="on"/><?php _e( 'Enable', 'newspaper-mag' );?><br />
        <input type="radio" <?php checked($meta,'off') ?> id="<?php echo $this->get_field_id( 'meta' ); ?>" name="<?php echo $this->get_field_name( 'meta' ); ?>" value="off"/><?php _e( 'Disable', 'newspaper-mag' );?><br />
      </p>
      <p><input type="radio" <?php checked($type, 'latest') ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="latest"/><?php _e( 'Show latest Posts', 'newspaper-mag' );?><br />
       <input type="radio" <?php checked($type,'category') ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="category"/><?php _e( 'Show posts from a category:', 'newspaper-mag' );?><br /></p>

      <p>
         <label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Select category', 'newspaper-mag' ); ?>:</label>
         <?php wp_dropdown_categories( array( 'show_option_none' =>' ','name' => $this->get_field_name( 'category' ), 'selected' => $category ) ); ?>
      </p>
      <?php
   }

   function update( $new_instance, $old_instance ) {
      $instance = $old_instance;
      $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
      $instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) );
      $instance[ 'number' ] = absint( $new_instance[ 'number' ] );
      $instance[ 'type' ] = strip_tags( $new_instance[ 'type' ] );
      $instance[ 'category' ] = absint( $new_instance[ 'category' ] );
      $instance[ 'meta' ] = strip_tags( $new_instance[ 'meta' ] );
      return $instance;
   }

   function widget( $args, $instance ) {
      extract( $args );
      extract( $instance );

      global $post;
      $title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '';
      $text = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
      $number = empty( $instance[ 'number' ] ) ? 5 : $instance[ 'number' ];
      $type = isset( $instance[ 'type' ] ) ? $instance[ 'type' ] : 'latest' ;
      $category = isset( $instance[ 'category' ] ) ? $instance[ 'category' ] : '';
      $meta = isset( $instance[ 'meta' ] ) ? $instance[ 'meta' ] : 'off' ;
      
      
      $category_link = get_category_link( $category ); 
      if ($category !='' && $type != 'latest' ) { 
          $cat_link = esc_url( $category_link );
      } else {
          $cat_link = get_permalink( get_option( 'page_for_posts' )); 
      }
       
      if( $type == 'latest' ) {
         $get_posts = new WP_Query( array(
            'posts_per_page'        => $number,
            'post_type'             => 'post',
            'ignore_sticky_posts'   => true
         ) );
      }
      else {
         $get_posts = new WP_Query( array(
            'posts_per_page'        => $number,
            'post_type'             => 'post',
            'category__in'          => $category
         ) );
      }
      echo $before_widget;
      ?>
      <?php
         if ( !empty( $title ) ) { echo $before_title . esc_html( $title ) . $after_title; }
         if( !empty( $text ) ) { ?> <p class="widget-description col-md-12"> <?php echo esc_textarea( $text ); ?> </p> <?php } ?>
         <?php
         while( $get_posts->have_posts() ) : $get_posts->the_post();
            ?>
              <div class="col-sm-4">
               <article> 
                <div <?php post_class(); ?>>                            
                  <div class="featured-thumbnail">
                    <a href="<?php the_permalink(); ?>" rel="bookmark">   
                      <?php if ( has_post_thumbnail() ) : ?>                             
                        <?php the_post_thumbnail('newspaper-mag-home'); ?>                                                           
                      <?php else : ?>
                        <img src="<?php echo get_template_directory_uri(); ?>/img/noprew-related.jpg" alt="<?php the_title(); ?>">                                                           
                      <?php endif; ?>
                    </a>
                  </div> 
                  <div class="home-header"> 
                  <header>
                  <h2 class="page-header">                                
                    <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( sprintf( __( 'Permalink to %s', 'newspaper-mag' ), the_title_attribute( 'echo=0' ) ) ); ?>" rel="bookmark">
                      <?php the_title(); ?>
                    </a>                            
                  </h2> 
                  <?php if( $meta == 'on') : ?>
                    <?php get_template_part('template-part', 'postmeta'); ?>
                  <?php endif; ?>   
                  </header>                                                      
                    <div class="entry-summary">
                  		<?php $content = get_the_content();  echo wp_trim_words( strip_shortcodes($content) , '10', $more = '...' ); ?> 
                  	</div><!-- .entry-summary -->                                                                                                                                                                
                  </div>                      
                </div>
                </article>
           </div>
         <?php  
         endwhile;
         wp_reset_query();
         ?>
         <?php if ($type == 'category') { ?>
           <div class="widget-footer col-md-12 text-right">
              <a class="btn btn-primary btn-xs" href="<?php echo esc_url( $cat_link ); ?>" >
                  <?php _e( 'All ', 'newspaper-mag' )?><?php $categorys = get_category($category); echo esc_attr( $categorys->category_count ); ?><?php _e( ' Articles', 'newspaper-mag' )?>
              </a>
            </div>
          <?php } elseif ($type == 'latest' && get_option('page_for_posts') == true ) { ?>
           <div class="widget-footer col-md-12 text-right">
              <a class="btn btn-primary btn-xs" href="<?php echo get_post_type_archive_link( 'post' ); ?>" >
                  <?php _e( 'All ', 'newspaper-mag' )?><?php $count_posts = wp_count_posts(); echo $count_posts->publish; ?><?php _e( ' Articles', 'newspaper-mag' )?>
              </a>
            </div>
          <?php } ?> 
      <!-- </div> -->
      <?php echo $after_widget;
      }
}

/**
 * Featured category  Widget
 */
class newspaper_mag_category_widget extends WP_Widget {

   function __construct() {
      $widget_ops = array( 'classname' => 'widget_category newspaper-mag-widget row', 'description' =>__( 'Display specific categories and weather forecast if is WCP OpenWeather plugin activated. Only for Front Page: Content Section!' , 'newspaper-mag') );
      $control_ops = array( 'width' => 200, 'height' =>250 );
      parent::__construct( false,$name= __( 'First Mag: Category list', 'newspaper-mag' ),$widget_ops);
   }

   function form( $instance ) {
      $newspaper_mag_defaults['title'] = '';
      $newspaper_mag_defaults['text'] = '';
      $newspaper_mag_defaults['select'] = '';
      $instance = wp_parse_args( (array) $instance, $newspaper_mag_defaults );
      $title = esc_attr( $instance[ 'title' ] );
      $text = esc_textarea( $instance['text'] );
      $select = $instance['select'];
      ?>
      <p><?php _e( 'Widget Layout:', 'newspaper-mag' ) ?></p>
      <div style="text-align: center;"><img src="<?php echo get_template_directory_uri() . '/img/fullwidth-cat.jpg'?>"></div>
      <p>
         <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e( 'Title:', 'newspaper-mag' ); ?></label>
         <input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
      </p>
      <?php _e( 'Description','newspaper-mag' ); ?>
      <textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php echo $text; ?></textarea>
      <?php
      $args = array(
                      'taxonomy'      => 'category',
                      'orderby'       => 'name',
                      'order'         => 'ASC',
                      'hierarchical'  => 1,
                      'pad_counts'    => 0
                  );
      $get_cats = get_categories( $args );
      echo '<p>' . _e( 'Select Categories:', 'newspaper-mag' ) . '</p>';
      if( $get_cats )
        {
            printf(
                '<select multiple="multiple" name="%s[]" id="%s" class="widefat" size="8">',
                $this->get_field_name('select'),
                $this->get_field_id('select')
            );
            foreach( $get_cats as $cats )
            {
                printf(
                    '<option value="%s" class="hot-topic" %s style="margin-bottom:3px;">%s</option>',
                    $cats->term_id,
                    in_array( $cats->term_id, $select) ? 'selected="selected"' : '',
                    $cats->name
                );
            }
            echo '</select>';
        }
        else
            echo 'No categories found :(';
   }

   function update( $new_instance, $old_instance ) {
      $instance = $old_instance;
      $instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
      $instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) );
      $instance['select'] = esc_sql( $new_instance['select'] );
      return $instance;
   }

   function widget( $args, $instance ) {
      extract( $args );
      extract( $instance );
      include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
      global $post;
      $title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '';
      $text = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
      echo $before_widget;
      if ( is_plugin_active( 'wcp-openweather/wcp-openweather.php' ) ) { $columns = 'col-md-6'; $cat_columns = 'col-md-4 col-sm-4 col-xs-6';} else {$columns = 'col-md-12'; $cat_columns = 'col-md-2 col-sm-4 col-xs-6';};
      ?>
      <?php
         if ( !empty( $title ) ) { echo $before_title . esc_html( $title ) . $after_title; } else {echo $before_title . date('l jS F Y') . $after_title;}
         if( !empty( $text ) ) { ?> <p class="widget-description col-md-12"> <?php echo esc_textarea( $text ); ?> </p> <?php } ?>
          <div class="single-category <?php echo $columns; ?>">
              <?php 
              $args = array(
                      'taxonomy'      => 'category',
                      'orderby'       => 'name',
                      'order'         => 'ASC',
                      'include'       => $select,
                      'hierarchical'  => 1,
                      'pad_counts'    => 0
                  );
              $categories = get_categories( $args );
              foreach ( $categories as $category ){
                  echo '<div class="single-category-inner '.$cat_columns.'"><a href="'. get_category_link( $category->term_id ) . '">'. esc_html( $category->name ) . '</a></div>';
              } ?>     
          </div>
          <div class="weather-block <?php echo $columns; ?>">
           <?php
            if ( is_plugin_active( 'wcp-openweather/wcp-openweather.php' ) ) {
              echo do_shortcode( '[wcp_weather id="weather-newspaper" template="compact" showCurrentWeather="on" showForecastWeather="on"]' );
            }
            ?>
          </div> 
      <!-- </div> -->
      <?php echo $after_widget;
      }
}
/****************************************************************************************/
